<?php 

/*
Plugin Name: Current Location
Plugin URI: http://jdg.futbal.net/index.php/current-location-plugin/?from=current_location-plugin
Description: Gets your current location from <a href="http://www.google.com/latitude/apps/badge">Google Badge System</a>. Use <code>&lt;?php display_current_location(); ?&gt;</code> to display your current location.
Version: 1.4
Author: Justin D. Givens
Author URI: http://jdg.futbal.net/?from=author_name-plugin
Copyright 2009 Justin D. Givens

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

function display_current_location() {
	$amount = func_num_args();
	
	//Stores the settings
	$settings = get_option("current_location_plugin");
	$is_Checked = $settings["current_location_temp_check"];
	$loc_userID = $settings["current_location_userid"];
	$loc_tempLoc = $settings["current_location_temp_location"];
	$loc_date_format = $settings["current_location_date"];
	$map_width = $settings["current_location_map_width"];
	$map_height = $settings["current_location_map_height"];
	$map_type = $settings["current_location_map_type"];
	$map_zoom = $settings["current_location_map_zoom"];
	
	if ($map_width == "") { $map_width = "180"; }
	if ($map_height == "") { $map_height = "300"; }
	if ($map_zoom > 0 ) { $map_zoom = "&z=". $map_zoom; } else { $map_zoom = ""; }
	
	//Checking for nulls
	if ($loc_userID == "") { $loc_userID = "Nothing"; }
	if ($loc_date_format == "") { $loc_date_format = "M j, Y g:i a"; }
	
	$feed = "http://www.google.com/latitude/apps/badge/api?user=". $loc_userID ."&type=json";

	//use cURL and grab the feed
	$ch = curl_init() or die ( curl_error() );
	curl_setopt( $ch, CURLOPT_URL, "$feed" );
	curl_setopt( $ch, CURLOPT_RETURNTRANSFER, 1 );
	$data = curl_exec( $ch );
	curl_close( $ch );
	
	//decode the json file and store it.
	$loc_data = json_decode($data);
	
	if(strtoupper($is_Checked) == "VAC")
	{
		//If user is on Vacation
		echo $loc_tempLoc;
	} else {
		if ($loc_data->features[0] == NULL)
		{
			//Means the User_ID Failed to return the the correct file.
			//output Default
			echo "<strong>User ID incorrect. You entered this id: $loc_userID</strong>";
		} else {
			//User_ID returned the full file.
			//Store everything here.
			$new_Date = fixDate($loc_data->features[0]->properties->timeStamp);
			$temp_date = date($loc_date_format,$new_Date) . "<br />";
			$temp_reverse = $loc_data->features[0]->properties->reverseGeocode . "<br />";
			$temp_accuracy = $loc_data->features[0]->properties->accuracyInMeters . " meters<br />";
			$temp_coords = $loc_data->features[0]->geometry->coordinates[1] . ", " . $loc_data->features[0]->geometry->coordinates[0] . "<br />";
			
			if ($amount == 0) { 
				echo $temp_reverse; 
			} else {
				for ($x = 0; $x < $amount; $x++)
				{
					//Loop | arguments to see which one are being used. 
					//Using strtoupper() to make all the arguments uppercase so it doesn't matter if they pass date|Date|DATE it will come out as DATE.					
					if (strtoupper(func_get_arg($x)) == "DATE") { echo $temp_date; }
					else if (strtoupper(func_get_arg($x)) == "CITY") { echo $temp_reverse; }		
					else if (strtoupper(func_get_arg($x)) == "ACCURACY") { echo $temp_accuracy; }
					else if (strtoupper(func_get_arg($x)) == "COORDS") { echo $temp_coords; }
					else if (strtoupper(func_get_arg($x)) == "MAP") { echo "<iframe src=\"http://www.google.com/latitude/apps/badge/api?user=$loc_userID&type=iframe&maptype=$map_type$map_zoom\" width=\"$map_width\" height=\"$map_height\" frameborder=\"0\"></iframe><br />"; }
					else { /* Do Nothing */ }
				}
			}
		}
	}
}

add_action('admin_menu', 'current_location_menu');
add_action('admin_menu', 'current_location_create_meta_box' );
add_action('save_post', 'current_location_save_meta_data' );
add_filter('the_content', 'current_location_tag');

function current_location_tag($content)
{
	global $post;
	if (get_post_meta($post->ID, 'current_location', true) != "") 
		$content = $content . '<p>Posted from: ' . get_post_meta($post->ID, 'current_location', true) . '</p>';
	return $content;
}

function current_location_create_meta_box() {
	global $theme_name;

	add_meta_box('post-meta-boxes', 'Current Location Post options', 'post_meta_boxes', 'post', 'normal');
	add_meta_box('page-meta-boxes', 'Current Location Page options', 'page_meta_boxes', 'page', 'normal');
}

function current_location_meta_boxes() {

	/* Array of the meta box options. */
	$meta_boxes = array(
		'title' => array('name' => 'current_location', 'title' => 'Display/Store Current Location?', 'type' => 'checkbox')
	);

	return apply_filters('current_location_meta_boxes', $meta_boxes);
}

function post_meta_boxes() {
	global $post;
	$meta_boxes = current_location_meta_boxes(); ?>

	<table class="form-table">
	<?php foreach ($meta_boxes as $meta) :

		$value = get_post_meta($post->ID, $meta['name'], true);

		get_meta_text_input($meta, $value);
		
	endforeach; ?>
	</table>
<?php
}

function page_meta_boxes() {
	global $post;
	$meta_boxes = current_location_meta_boxes(); ?>

	<table class="form-table">
	<?php foreach ( $meta_boxes as $meta ) :

		$value = get_post_meta( $post->ID, $meta['name'], true );

		get_meta_text_input($meta, $value);

	endforeach; ?>
	</table>
<?php
}

function get_meta_text_input($args = array(),$value = false )
{	
	extract( $args );
	?>
	<tr>
		<th style="width:25%;">
			<label for="<?php echo $name; ?>"><?php echo $title; ?></label>
		</th>
		<td>
			<input type="<?php echo $type; ?>" name="<?php echo $name; ?>" id="<?php echo $name; ?>" value="<?php display_current_location();?>"<?php if (wp_specialchars($value, 1) != "") {?> checked="checked"<?php } ?> />
			<input type="hidden" name="<?php echo $name; ?>_noncename" id="<?php echo $name; ?>_noncename" value="<?php echo wp_create_nonce( plugin_basename( __FILE__ ) ); ?>" />
		</td>
	</tr>
  <tr>
  	<td colspan="2">Current Location: <?php display_current_location();?></td>
  </tr>
	<?
}

function current_location_save_meta_data($post_id) {
	global $post;

	if ( 'page' == $_POST['post_type'] )
		$meta_boxes = array_merge(current_location_meta_boxes() );
	else
		$meta_boxes = array_merge(current_location_meta_boxes() );

	foreach ( $meta_boxes as $meta_box ) :

		if ( !wp_verify_nonce( $_POST[$meta_box['name'] . '_noncename'], plugin_basename( __FILE__ ) ) )
			return $post_id;

		if ( 'page' == $_POST['post_type'] && !current_user_can( 'edit_page', $post_id ) )
			return $post_id;

		elseif ( 'post' == $_POST['post_type'] && !current_user_can( 'edit_post', $post_id ) )
			return $post_id;

		$data = stripslashes( $_POST[$meta_box['name']] );
		
		if ( get_post_meta( $post_id, $meta_box['name'] ) == '' )
			add_post_meta( $post_id, $meta_box['name'], $data, true );

		elseif ( $data != get_post_meta( $post_id, $meta_box['name'], true ) )
			update_post_meta( $post_id, $meta_box['name'], $data );

		elseif ( $data == '' )
			delete_post_meta( $post_id, $meta_box['name'], get_post_meta( $post_id, $meta_box['name'], true ) );

	endforeach;
}

function fixDate($incoming_timeStamp)
{
	global $wp_version;
	//Function to take in the GMT and fix the time.
	//Set the timezone default if you are using WP 2.8 or higher.
	//If you don't have 2.8 or higher then it unix timestamp will return the server time. Not the Blog local time. 
	if ($wp_version >= 2.8)
	{
		date_default_timezone_set(get_option('timezone_string'));
	}
	return $incoming_timeStamp;
}

function current_location_menu() {
  //add_submenu_page('plugins.php','Current Location Settings', 'Current Location', 8, __FILE__, 'current_location_options');
  add_menu_page("Current Location Settings", "Current Location",8, __FILE__, 'current_location_options', WP_PLUGIN_URL.'/'.str_replace(basename( __FILE__),"",plugin_basename(__FILE__)) . 'icon.png');
}

function current_location_options() {
	global $wp_version;
	$options = get_option("current_location_plugin");
	if (!is_array($options)) {
		$options["current_location_userid"] = "Enter Here";
		$options["current_location_date"] = "M d, Y g:i a";
		$options["current_location_temp_check"] = "";
		$options["current_location_temp_location"] = "";
		$options["current_location_map_width"] = "180";
		$options["current_location_map_height"] = "300";
		$options["current_location_map_type"] = "road";
		$options["current_location_map_zoom"] = "0";
	}

	// If the user has submitted their options, grab them here.
	if ($_POST['CL_SAVE']) {
		//Main settings were updated/saved.
		$options["current_location_userid"] = htmlspecialchars($_POST["user_id"]);
		$options["current_location_date"] = htmlspecialchars($_POST["format_date"]);
		$options["current_location_temp_check"] = htmlspecialchars($_POST["temp_check"]);
		//Checking to see if vacation is checked. 
		if ($options["current_location_temp_check"] == "Vac")
		{
			$options["current_location_temp_location"] = htmlspecialchars($_POST["temp_location"]);
		} else {
			$options["current_location_temp_location"] = "";
		}
		update_option("current_location_plugin", $options);
	}
	if ($_POST['ML_SAVE']) {
		//Map settings were updated/saved. 
		$width = htmlspecialchars($_POST["maps_width"]);
		$height = htmlspecialchars($_POST["maps_height"]);
		if ($width == "") { $width = "180"; }
		if ($height == "") { $height = "300"; }
		$options["current_location_map_width"] = $width;
		$options["current_location_map_height"] = $height;
		$options["current_location_map_type"] = htmlspecialchars($_POST["maps_type"]);
		$options["current_location_map_zoom"] = htmlspecialchars($_POST["maps_zoom"]);
		update_option("current_location_plugin", $options);
	}
	
	if ($wp_version >= 2.8)
	{
		$cl_timezone = get_option('timezone_string');
		if ($cl_timezone == "")
		{
			$cl_timezone = "Timezone not set. Go to Settings > General";
		}
	} else {
		$cl_timezone = "Since you are using an older version of WordPress, the timestamp output will be set to the server.";
	}

	$id = $options["current_location_userid"];
	$format_date = $options["current_location_date"];
	$temp_check = $options["current_location_temp_check"];
	$temp_location = $options["current_location_temp_location"];
	$temp_width = $options["current_location_map_width"];
	$temp_height = $options["current_location_map_height"];
	$temp_type = $options["current_location_map_type"];
	$temp_zoom = $options["current_location_map_zoom"];
	
	///Testing to see if Vacation is turned on. If so check it and fill in the info. If no, don't display anything.
	if ($temp_check == "Vac") { $temp_check1 = "checked=\"checked\""; $temp_location = $options["current_location_temp_location"]; } else { $temp_check1 = ""; $temp_location = ""; }
	
	//Testing to see which option needs to be selected in the maps_type field. 
	if ($temp_type == "satellite") { $satellite_select = "SELECTED";$terrain_select = "";$hybrid_select = "";$road_select = ""; } else if ($temp_type == "terrain") { $satellite_select = "";$terrain_select = "SELECTED";$hybrid_select = "";$road_select = ""; } else if ($temp_type == "hybrid") { $satellite_select = "";$terrain_select = "";$hybrid_select = "SELECTED";$road_select = ""; } else { $satellite_select = "";$terrain_select = "";$hybrid_select = "";$road_select = "SELECTED"; }
	
	//Testing to see which options needs t obe selected in the maps_zoom field.
	if ($temp_zoom == "3") { $continent_select = "SELECTED";$city_select = "";$region_select = "";$country_select = "";$auto_select = ""; } else if ($temp_zoom == "10") { $continent_select = "";$city_select = "SELECTED";$region_select = "";$country_select = "";$auto_select = ""; } else if ($temp_zoom == "7") { $continent_select = "";$city_select = "";$region_select = "SELECTED";$country_select = "";$auto_select = ""; } else if ($temp_zoom == "5") { $continent_select = "";$city_select = "";$region_select = "";$country_select = "SELECTED";$auto_select = ""; } else { $continent_select = "";$city_select = "";$region_select = "";$country_select = "";$auto_select = "SELECTED"; }
	
	echo <<<SETTINGS_DISPLAY
<style type="text/css">
<!--
label {font-weight:bold;}
fieldset {padding:1.4em;margin:0 0.75em 1.5em 0;border:1px solid #ccc; width:80%; float:left; border-radius:5px; -moz-border-radius:5px; -webkit-border-radius:5px; }
legend {font-weight:bold;font-size:1.2em;}
input.text, input.title, textarea, select {margin:0.5em 0;border:1px solid #bbb;}
input.text:focus, input.title:focus, textarea:focus, select:focus {border:1px solid #666;}
input.text, input.title {width:300px;padding:5px;}
input.title {font-size:1.5em;}
textarea {width:390px;height:250px;padding:5px;}
code {border:1px #333 dotted; background:inherit;}
-->
</style>
<div class="wrap">
  <form id="form1" name="form1" method="post" action="">
    <fieldset>
    <legend>Settings for <a title="Plugin Homepage" href="http://jdg.futbal.net/?from=plugin-settings-name">Current Location Plugin 1.4</a> | By: <a href="http://jdg.futbal.net/?from=plugin-settings-author">Justin D. Givens</a></legend>
    <p>
      <label for="user_id">User ID:
      <input name="user_id" type="text" id="user_id" size="25" value="$id" />
      </label>
      <br />
      <label for="format_date">Date Format:
      <input name="format_date" type="text" id="format_date" size="25" value="$format_date" />
      </label>
      - Default Format is: <strong>M j, Y g:i a</strong>. Use the <a title="PHP Date" href="http://us3.php.net/manual/en/function.date.php">PHP Date</a> page to learn how to do different formating. </p>
    <p>Get your User ID from here: <a title="Gogole Badge System" href="http://www.google.com/latitude/apps/badge">Google Badge System</a>. Its is the Id number after "api?user=". <br />
      Example: http://www.google.com/latitude/apps/badge/api?user=-123456789&type=json <br />
      User ID is: <strong>-123456789</strong> </p>
    <p>Sometimes you don't want to update your location (example: vacation). Check this box below and manually enter a location or message.<br />
      <input name="temp_check" type="checkbox" id="temp_check" value="Vac" $temp_check1 />
      <label for="temp_location">Vacation Text:
      <input name="temp_location" type="text" id="temp_location" size="30" value="$temp_location" />
      </label>
    </p>
	<p>Current Timezone: <strong>$cl_timezone</strong></p>
    <p class="submit">
      <input type="submit" name="CL_SAVE" id="CL_SAVE" value="Save" />
    </p>
    </fieldset>
  </form>
  <form id="form2" name="form2" method="post" action="">
    <fieldset>
    <legend>Maps Settings</legend>
      <label for="maps_width">Width:
      <input name="maps_width" type="text" id="maps_width" size="5" value="$temp_width" />
      </label>
      <label for="maps_height">Height:
      <input name="maps_height" type="text" id="maps_height" size="5" value="$temp_height" />
      </label>
      - Default Settings are: <strong>180x300</strong>.
      <br />
      <label for="maps_type">Map type:
      <select name="maps_type">
        <option $road_select value="roadmap">Road</option>
        <option $terrain_select value="terrain">Terrain</option>
        <option $hybrid_select value="hybrid">Hybrid</option>
        <option $satellite_select value="satellite">Satellite</option>
      </select>
      </label>
      - Default Settings is: <strong>Road</strong>.
      <br />
      <label for="maps_zoom">Zoom Level:
      <select name="maps_zoom">
        <option $auto_select value="0">Automatic</option>
        <option $city_select value="10">City</option>
        <option $region_select value="7">Region</option>
        <option $country_select value="5">Country</option>
        <option $continent_select value="3">Continent</option>
      </select>
      </label>
      - Default Settings is: <strong>Automatic</strong>.
    <p class="submit">
      <input type="submit" name="ML_SAVE" id="ML_SAVE" value="Update" />
    </p>
    </fieldset>
  </form>
  <fieldset style="width:40%; float:left;">
  <legend>How to use the Plugin</legend>
  <p>Use this in your template to display your current location: <code>display_current_location();</code><br />
    You can choose what to display or by default it will just display City Level. You can pass any of these and they will display in that order.
  <ul>
    <li><strong>city</strong> :: Display Reverse Geocode (Usually City)</li>
    <li><strong>coords</strong> :: Display Coordinates</li>
    <li><strong>accuracy</strong> :: Display Accuracy In Meters</li>
    <li><strong>date</strong> :: Display Last Updated</li>
    <li><strong>map</strong> :: Display Map - Little Google Map</li>
  </ul>
	<p>Note: To display your current location in a post, use the Current Location Options in the new post screen.</p>
  </fieldset>
  <fieldset style="width:36%; float:left; margin-left:10px; margin-right:0;">
  <legend>Example of the Outputs</legend>
  <p><code>display_current_location();</code> would output this: <br/>
    Nashville, TN, USA </p>
  <p><code>display_current_location("city", "accuracy");</code> would output this: <br/>
    Nashville, TN, USA<br/>
    2253 meters </p>
  <p><code>display_current_location("city", "date", "coords", "accuracy");</code> would output this: <br/>
    Nashville, TN, USA<br/>
    Jun 12, 2009 2:34 am<br/>
    -86.682559, 36.085679<br/>
    2253 meters </p>
  </fieldset>
</div>
SETTINGS_DISPLAY;
}
?>